summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorEli Zaretskii <eliz@gnu.org>2016-02-22 19:30:01 +0200
committerEli Zaretskii <eliz@gnu.org>2016-02-22 19:30:01 +0200
commit6bd9d697fd6d81726fa684fa86ef7369a1ef93de (patch)
tree40abfd24aca2afb463c174cb93ea20cfb3687328
parent8c22ac9115a20e84f38a0b6e262756f43ea72f05 (diff)
downloademacs-6bd9d697fd6d81726fa684fa86ef7369a1ef93de.tar.gz
Fix documentation of 'global-disable-point-adjustment'
* src/keyboard.c (syms_of_keyboard) <disable-point-adjustment> <global-disable-point-adjustment>: Doc fixes. (Bug#22771)
-rw-r--r--src/keyboard.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/keyboard.c b/src/keyboard.c
index 4edb5aa0f32..31208696032 100644
--- a/src/keyboard.c
+++ b/src/keyboard.c
@@ -11620,10 +11620,10 @@ It's called with one argument, the help string to display. */);
DEFVAR_LISP ("disable-point-adjustment", Vdisable_point_adjustment,
doc: /* If non-nil, suppress point adjustment after executing a command.
-After a command is executed, if point is moved into a region that has
-special properties (e.g. composition, display), we adjust point to
-the boundary of the region. But, when a command sets this variable to
-non-nil, we suppress the point adjustment.
+After a command is executed, if point moved into a region that has
+special properties (e.g. composition, display), Emacs adjusts point to
+the boundary of the region. But when a command binds this variable to
+non-nil, this point adjustment is suppressed.
This variable is set to nil before reading a command, and is checked
just after executing the command. */);
@@ -11631,9 +11631,9 @@ just after executing the command. */);
DEFVAR_LISP ("global-disable-point-adjustment",
Vglobal_disable_point_adjustment,
- doc: /* If non-nil, always suppress point adjustment.
+ doc: /* If non-nil, always suppress point adjustments.
-The default value is nil, in which case, point adjustment are
+The default value is nil, in which case point adjustments are
suppressed only after special commands that set
`disable-point-adjustment' (which see) to non-nil. */);
Vglobal_disable_point_adjustment = Qnil;